@@ -21,6 +21,7 @@
 #    misrepresented as being the original software.
 # 3. This notice may not be removed or altered from any source distribution.
 
+import sys
 import os, unittest
 import pysqlite2.dbapi2 as sqlite
 
@@ -31,7 +32,7 @@ class TransactionTests(unittest.TestCase):
     def setUp(self):
         try:
             os.remove(get_db_path())
-        except:
+        except OSError:
             pass
 
         self.con1 = sqlite.connect(get_db_path(), timeout=0.1)
@@ -47,7 +48,10 @@ class TransactionTests(unittest.TestCase):
         self.cur2.close()
         self.con2.close()
 
-        os.unlink(get_db_path())
+        try:
+            os.unlink(get_db_path())
+        except OSError:
+            pass
 
     def CheckDMLdoesAutoCommitBefore(self):
         self.cur1.execute("create table test(i)")
@@ -109,6 +113,10 @@ class TransactionTests(unittest.TestCase):
         self.failUnlessEqual(len(res), 1)
 
     def CheckRaiseTimeout(self):
+        if sqlite.sqlite_version_info < (3, 2, 2):
+            # This will fail (hang) on earlier versions of sqlite.
+            # Determine exact version it was fixed. 3.2.1 hangs.
+            return
         self.cur1.execute("create table test(i)")
         self.cur1.execute("insert into test(i) values (5)")
         try:
@@ -124,6 +132,10 @@ class TransactionTests(unittest.TestCase):
         This tests the improved concurrency with pysqlite 2.3.4. You needed
         to roll back con2 before you could commit con1.
         """
+        if sqlite.sqlite_version_info < (3, 2, 2):
+            # This will fail (hang) on earlier versions of sqlite.
+            # Determine exact version it was fixed. 3.2.1 hangs.
+            return
         self.cur1.execute("create table test(i)")
         self.cur1.execute("insert into test(i) values (5)")
         try:
